@@ -787,6 +787,22 @@ being set it is automatically widened."
 (unless footnote-minor-mode-map
   (define-key global-map footnote-prefix footnote-mode-map))
 
+;;;###autoload
+(if (progn (condition-case () (require 'easymenu) (error nil))
+	   (fboundp 'easy-menu-add-item))
+    (easy-menu-add-item nil '("Cmds")
+			'("Footnotes"
+			  ["Add Footnote" Footnote-add-footnote t]
+			  ["Delete Footnote" Footnote-delete-footnote t]
+			  ["Goto Footnote" Footnote-goto-footnote t]
+			  ["Back to Message" Footnote-back-to-message t]
+			  ["Renumber Footnotes" Footnote-renumber-footnotes t]
+			  "--"
+			  ["Set Footnote Style" Footnote-set-style t]
+			  ["Cycle Footnote Style" Footnote-cycle-style t]
+			  )))
+
+
 ;;;###autoload
 (defun footnote-mode (&optional arg)
   "Toggle footnote minor mode.
@@ -794,12 +810,14 @@ being set it is automatically widened."
 key		binding
 ---		-------
 
+\\[Footnote-set-style]			Footnote-set-style
 \\[Footnote-renumber-footnotes]		Footnote-renumber-footnotes
 \\[Footnote-goto-footnote]		Footnote-goto-footnote
 \\[Footnote-delete-footnote]		Footnote-delete-footnote
 \\[Footnote-cycle-style]		Footnote-cycle-style
 \\[Footnote-back-to-message]		Footnote-back-to-message
 \\[Footnote-add-footnote]		Footnote-add-footnote
+
 "
   (interactive "*P")
   ;; (filladapt-mode t)
